Module engine

Module engine 

Structs

Configured
Marker for a configured component in the typestate pattern.
Engine
The central orchestrator for Engine.
EngineBuilder
A builder for configuring and creating an Engine instance.
Missing
Marker for a missing component in the typestate pattern.

Traits

HasSessionStore
Trait for Engine instances that have a session store configured.
HasTokenManager
Trait for Engine instances that have a token manager configured.
SessionStoreState
Trait for the session store state in the Engine.
TokenManagerState
Trait for the token manager state in the Engine.