EngineBuilder

Struct EngineBuilder 

pub struct EngineBuilder<S = Missing, T = Missing> { /* private fields */ }
A builder for configuring and creating an Engine instance.

Implementations

Source

impl<S, T> EngineBuilder<S, T>

pub fn provider<F>(self, flow: F) -> Self
where F: ErasedOAuthFlow + 'static,

Register an OAuth provider flow.

pub fn with_auth_method<M>(self, method: M) -> Self
where M: AuthMethod + 'static,

Register a local authentication method.

pub fn with_mfa_method<M>(self, method: M) -> Self
where M: AuthMethod + 'static,

Register a local authentication method to be used EXCLUSIVELY for step-up MFA challenges.

pub fn session_store( self, store: Arc<dyn SessionStore>, ) -> EngineBuilder<Configured<Arc<dyn SessionStore>>, T>

Set the session store.

pub fn token_manager( self, manager: Arc<TokenManager>, ) -> EngineBuilder<S, Configured<Arc<TokenManager>>>

Set the token manager.

pub fn jwt_secret( self, secret: &[u8], ) -> EngineBuilder<S, Configured<Arc<TokenManager>>>

Set the JWT secret for the default token manager.

pub fn session_config(self, config: SessionConfig) -> Self

Set the session configuration.

pub fn build(self) -> Engine<S, T>

Build the Engine.