Module strategy

Module strategy 

Strategy-based authentication.

Modules

utils
Utility functions for common authentication tasks.

Structs

BasicStrategy
Strategy for Basic authentication.
HeaderStrategy
Strategy for custom header authentication.
SessionStrategy
Strategy for Session authentication.
TokenStrategy
Strategy for Token (Bearer) authentication.

Traits

AuthenticationStrategy
Trait for an authentication strategy.
BasicAuthenticator
Trait for a provider that validates username and password (Basic Auth).
SessionProvider
Trait for a session store that can load an identity.
TokenValidator
Trait for a validator that verifies a token.