Strategy-based authentication.
Modules
- utils
- Utility functions for common authentication tasks.
Structs
- Basic
Strategy - Strategy for Basic authentication.
- Header
Strategy - Strategy for custom header authentication.
- Session
Strategy - Strategy for Session authentication.
- Token
Strategy - Strategy for Token (Bearer) authentication.
Traits
- Authentication
Strategy - Trait for an authentication strategy.
- Basic
Authenticator - Trait for a provider that validates username and password (Basic Auth).
- Session
Provider - Trait for a session store that can load an identity.
- Token
Validator - Trait for a validator that verifies a token.