Engine

Struct Engine 

pub struct Engine<S = Missing, T = Missing> {
    pub providers: HashMap<String, Arc<dyn ErasedOAuthFlow>>,
    pub session_store: S,
    pub session_config: SessionConfig,
    pub token_manager: T,
}
The central orchestrator for Authkestra.

Engine ties together authentication methods, session management, and flows. It is constructed using the EngineBuilder which uses the Typestate pattern to ensure that certain methods are only available when the necessary components are configured.

Fields

providers: HashMap<String, Arc<dyn ErasedOAuthFlow>>

Map of registered OAuth providers.

session_store: S

The session storage backend.

session_config: SessionConfig

Configuration for session cookies.

token_manager: T

Manager for JWT signing and verification.

Implementations

Source

impl Engine<Missing, Missing>

pub fn builder() -> EngineBuilder<Missing, Missing>

Start building a new Engine.

Source

impl<T> Engine<Configured<Arc<dyn SessionStore>>, T>

pub fn session_store(&self) -> Arc<dyn SessionStore>

Get the session store.

pub async fn create_session( &self, identity: Identity, ) -> Result<Session, AuthError>

Create a new session for the given identity.

Source

impl<S> Engine<S, Configured<Arc<TokenManager>>>

pub fn token_manager(&self) -> Arc<TokenManager>

Get the token manager.

pub fn issue_token( &self, identity: Identity, expires_in_secs: u64, ) -> Result<String, AuthError>

Issue a JWT for the given identity.