pub struct EngineBuilder<S = Missing, T = Missing> { /* private fields */ }Expand description
A builder for configuring and creating an Engine instance.
Implementations
Sourceimpl<S, T> EngineBuilder<S, T>
impl<S, T> EngineBuilder<S, T>
Sourcepub fn provider<F>(self, flow: F) -> Selfwhere
F: ErasedOAuthFlow + 'static,
pub fn provider<F>(self, flow: F) -> Selfwhere
F: ErasedOAuthFlow + 'static,
Register an OAuth provider flow.
Sourcepub fn with_auth_method<M>(self, method: M) -> Selfwhere
M: AuthMethod + 'static,
pub fn with_auth_method<M>(self, method: M) -> Selfwhere
M: AuthMethod + 'static,
Register a local authentication method.
Sourcepub fn with_mfa_method<M>(self, method: M) -> Selfwhere
M: AuthMethod + 'static,
pub fn with_mfa_method<M>(self, method: M) -> Selfwhere
M: AuthMethod + 'static,
Register a local authentication method to be used EXCLUSIVELY for step-up MFA challenges.
Sourcepub fn session_store(
self,
store: Arc<dyn SessionStore>,
) -> EngineBuilder<Configured<Arc<dyn SessionStore>>, T>
pub fn session_store( self, store: Arc<dyn SessionStore>, ) -> EngineBuilder<Configured<Arc<dyn SessionStore>>, T>
Set the session store.
Sourcepub fn token_manager(
self,
manager: Arc<TokenManager>,
) -> EngineBuilder<S, Configured<Arc<TokenManager>>>
pub fn token_manager( self, manager: Arc<TokenManager>, ) -> EngineBuilder<S, Configured<Arc<TokenManager>>>
Set the token manager.
Sourcepub fn jwt_secret(
self,
secret: &[u8],
) -> EngineBuilder<S, Configured<Arc<TokenManager>>>
pub fn jwt_secret( self, secret: &[u8], ) -> EngineBuilder<S, Configured<Arc<TokenManager>>>
Set the JWT secret for the default token manager.
Sourcepub fn session_config(self, config: SessionConfig) -> Self
pub fn session_config(self, config: SessionConfig) -> Self
Set the session configuration.