Enums
Traits
- Atomic
Consume - Backends that can atomically fetch-and-remove a value implement this.
- Atomic
Insert - Backends that can atomically insert a value only if no value is
currently stored under
keyimplement this. - Indexed
KvStore - Backends that can atomically write a value under a primary key while also maintaining a secondary lookup key implement this.
- KvStore
Functions
- ttl_
ceil_ secs - Rounds a
Durationup to the nearest whole second, flooring at 1.