Module store

Module store 

Enums

StoreError

Traits

AtomicConsume
Backends that can atomically fetch-and-remove a value implement this.
AtomicInsert
Backends that can atomically insert a value only if no value is currently stored under key implement this.
IndexedKvStore
Backends that can atomically write a value under a primary key while also maintaining a secondary lookup key implement this.
KvStore

Functions

ttl_ceil_secs
Rounds a Duration up to the nearest whole second, flooring at 1.