Module store

Module store 

Enums

StoreError

Traits

AtomicConsume
Backends that can atomically fetch-and-remove a value implement this.
IndexedKvStore
Backends that can atomically write a value under a primary key while also maintaining a secondary lookup key implement this.
KvStore